@@ -11,24 +11,22 @@ logger = logging.getLogger()
 
 
 def load_and_save(file_pro: DataFileProperty):
-    exchan = LoadDataKline(file_pro.exchange)
-    unix_start, unix_end = int(file_pro.start_date.timestamp() * 1000), int(file_pro.end_date.timestamp() * 1000)
-
     file_pro.sync()
 
-    if os.path.exists(file_pro.file_path_tar):
-        logger.info("file exists.")
+    if file_pro.tar_exists():
         return
 
+    exchan = LoadDataKline(file_pro.exchange)
+    unix_start, unix_end = int(file_pro.start_date.timestamp() * 1000), int(file_pro.end_date.timestamp() * 1000)
     # 下载
     exchan.load_all(timeframe=file_pro.timeframe, unix_start=unix_start, unix_end=unix_end)
     # 保存
-    exchan.table.to_csv_all(file_pro.file_path_csv, page_size=100000)
+    exchan.table.to_csv_all(file_pro.file_path_csv(), page_size=100000)
     # 压缩
-    with tarfile.open(file_pro.file_path_tar, "w:xz") as tar:
-        tar.add(file_pro.file_path_csv, arcname=file_pro.arcname(file_pro.file_path_csv))
+    with tarfile.open(file_pro.file_path_tar(), "w:xz") as tar:
+        tar.add(file_pro.file_path_csv(), arcname=file_pro.arcname(file_pro.file_path_csv()))
     # 删除
-    os.remove(file_pro.file_path_csv)
+    os.remove(file_pro.file_path_csv())
     exchan.table.delete_all()
 
 
